@@ -1,7 +1,8 @@
 #!/usr/bin/perl
 
+# nagios: -epn
 # --
-# check_cdot_global - Check powersupplys, fans, nvram status, temp or global health
+# check_cdot_global - Check powersupplies, fans, nvram status, temp or global health
 # Copyright (C) 2013 noris network AG, http://www.noris.net/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -12,17 +13,20 @@
 use 5.10.0;
 use strict;
 use warnings;
-use lib "/usr/lib/netapp-manageability-sdk-5.1/lib/perl/NetApp";
+use lib "/usr/lib/netapp-manageability-sdk/lib/perl/NetApp";
 use NaServer;
 use NaElement;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case);
+
+# ignore warning for experimental 'given'
+no if ($] >= 5.018), 'warnings' => 'experimental';
 
 GetOptions(
-    'hostname=s' => \my $Hostname,
-    'username=s' => \my $Username,
-    'password=s' => \my $Password,
+    'H|hostname=s' => \my $Hostname,
+    'u|username=s' => \my $Username,
+    'p|password=s' => \my $Password,
     'plugin=s'   => \my $Plugin,
-    'help|?'     => sub { exec perldoc => -F => $0 or die "Cannot execute perldoc: $!\n"; },
+    'h|help'     => sub { exec perldoc => -F => $0 or die "Cannot execute perldoc: $!\n"; },
 ) or Error("$0: Error in command line arguments\n");
 
 sub Error {
@@ -163,15 +167,14 @@ while(defined($next)){
 given ($Plugin) {
     when("power"){
         if ($sum_failed_power) {
-            print "CRITICAL: $sum_failed_power failed power supply(s): $failed_node\n";
+            print "CRITICAL: $sum_failed_power failed power supplie(s): $failed_node\n";
             exit 2;
         } else {
-            print "OK: No failed power supplys\n";
+            print "OK: No failed power supplies\n";
             exit 0;
         }
-	}
+    }
     when("fan"){
-
         if ($sum_failed_fan) {
             print "CRITICAL: $sum_failed_fan failed fan(s): $failed_node\n";
             exit 2;
@@ -179,7 +182,7 @@ given ($Plugin) {
             print "OK: No failed fans\n";
             exit 0;
         }
-	}
+    }
     when("nvram"){
         if ($sum_failed_nvram) {
             print "CRITICAL: $sum_failed_nvram failed nvram(s): $failed_node\n";
@@ -188,7 +191,7 @@ given ($Plugin) {
             print "OK: No failed nvram\n";
             exit 0;
         }
-	}
+    }
     when("temp"){
         if ($sum_failed_temp) {
             print "CRITICAL: Temperature Overheating: $failed_node\n";
@@ -197,16 +200,16 @@ given ($Plugin) {
             print "OK: Temperature OK\n";
             exit 0;
         } 
-	}
-	when("health"){
-		if ($sum_failed_health){
+    }
+    when("health"){
+	    if ($sum_failed_health){
             print "CRITICAL: Health Status Critical: $failed_node\n";
             exit 2;
         } else {
             print "OK: Health Status OK\n";
             exit 0;
         }
-	}
+    }
 }
 
 __END__
@@ -215,17 +218,17 @@ __END__
 
 =head1 NAME
 
-check_cdot_global.pl - Checks health status ( powersupplys, fans, ... )
+check_cdot_global.pl - Checks health status ( powersupplies, fans, ... )
 
 =head1 SYNOPSIS
 
-check_cdot_global --hostname HOSTNAME --username USERNAME \
-           --password PASSWORD --plugin fan
+check_cdot_global -H HOSTNAME -u USERNAME \
+           -p PASSWORD --plugin PLUGIN
 
 =head1 DESCRIPTION
 
 Checks Health Status of:
-  * Power Supplys
+  * Power Supplies
   * Fans
   * NvRam status
   * Temperatuter
@@ -235,15 +238,15 @@ Checks Health Status of:
 
 =over 4
 
-=item --hostname FQDN
+=item -H | --hostname FQDN
 
 The Hostname of the NetApp to check
 
-=item --username USERNAME
+=item -u | --username USERNAME
 
 The Login Username of the NetApp to check
 
-=item --password PASSWORD
+=item -p | --password PASSWORD
 
 The Login Password of the NetApp to check
 
