@@ -1,5 +1,6 @@
 #!/usr/bin/perl
 
+# nagios: -epn
 # --
 # check_cdot_multipath - Check if all disks are multipathed (4 paths)
 # Copyright (C) 2013 noris network AG, http://www.noris.net/
@@ -9,11 +10,13 @@
 # did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 # --
 
+use Data::Dumper;
+
 use 5.10.0;
 use strict;
 use warnings;
 
-use lib "/usr/lib/netapp-manageability-sdk-5.1/lib/perl/NetApp";
+use lib "/usr/lib/netapp-manageability-sdk/lib/perl/NetApp";
 use NaServer;
 use NaElement;
 use Getopt::Long;
@@ -33,11 +36,36 @@ Error('Option --hostname needed!') unless $Hostname;
 Error('Option --username needed!') unless $Username;
 Error('Option --password needed!') unless $Password;
 
+my $must_paths;
+
 my $s = NaServer->new( $Hostname, 1, 3 );
 $s->set_transport_type("HTTPS");
 $s->set_style("LOGIN");
 $s->set_admin_user( $Username, $Password );
 
+# MCC check
+my $mcc_iterator = NaElement->new("metrocluster-get");
+my $mcc_response = $s->invoke_elem($mcc_iterator);
+
+my $mcc = $mcc_response->child_get("attributes");
+my $mcc_info = $mcc->child_get("metrocluster-info");
+my $config_state = $mcc_info->child_get_string("local-configuration-state");
+
+if($config_state eq "configured"){
+
+    my $type = $mcc_info->child_get_string("configuration-type");
+
+    if($type eq "stretch"){
+        $must_paths = 2;
+    } elsif($type eq "fabric"){
+        $must_paths = 8;
+    } else {
+        $must_paths = 4;
+    }
+} else {
+    $must_paths = 4;
+}
+
 my $iterator = NaElement->new("storage-disk-get-iter");
 my $tag_elem = NaElement->new("tag");
 $iterator->child_add($tag_elem);
@@ -61,17 +89,25 @@ while(defined($next)){
 	
 	my $heads = $output->child_get("attributes-list");
 	my @result = $heads->children_get();
-	
+
 	foreach my $disk (@result){
 	
 	    my $paths = $disk->child_get("disk-paths");
 	    my $path_count = $paths->children_get("disk-path-info");
 	    my $disk_name = $disk->child_get_string("disk-name");
+        my $path_info = $paths->child_get("disk-path-info");
 
-	    if ($path_count ne "4"){
-	        my @disk_name = split(/:/,$disk_name);
-	        push @failed_disks, $disk_name[1];
-		}
+        foreach my $path ($path_info){
+
+            my $disk_path_name = $path->child_get_string("disk-name");
+            my @split = split(/:/,$disk_path_name);
+
+            if((@split eq 2) && ($path_count ne $must_paths)){
+                unless($path_count > $must_paths){
+                    push @failed_disks, $disk_name;
+                }
+            }
+        }
 	}
 	$next = $output->child_get_string("next-tag");
 }
