@@ -1,5 +1,6 @@
 #!/usr/bin/perl
 
+# nagios: -epn
 # --
 # check_cdot_snapmirror - Checks SnapMirror Healthnes
 # Copyright (C) 2013 noris network AG, http://www.noris.net/
@@ -12,19 +13,29 @@
 use strict;
 use warnings;
 
-use lib "/usr/lib/netapp-manageability-sdk-5.1/lib/perl/NetApp";
+use lib "/usr/lib/netapp-manageability-sdk/lib/perl/NetApp";
 use NaServer;
 use NaElement;
 use Getopt::Long;
+use Data::Dumper;
 
 GetOptions(
     'hostname=s' => \my $Hostname,
     'username=s' => \my $Username,
     'password=s' => \my $Password,
     'lag=i'      => \my $LagOpt,
+    'volume=s'   => \my $VolumeName,
+    'vserver=s'  => \my $VServer,
+    'exclude=s'  => \my @excludelistarray,
+    'regexp'     => \my $regexp,
+    'v|verbose'  => \my $verbose,
     'help|?'     => sub { exec perldoc => -F => $0 or die "Cannot execute perldoc: $!\n"; },
 ) or Error("$0: Error in command line arguments\n");
 
+my %Excludelist;
+@Excludelist{@excludelistarray}=();
+my $excludeliststr = join "|", @excludelistarray;
+
 sub Error {
     print "$0: " . $_[0] . "\n";
     exit 2;
@@ -32,7 +43,7 @@ sub Error {
 Error('Option --hostname needed!') unless $Hostname;
 Error('Option --username needed!') unless $Username;
 Error('Option --password needed!') unless $Password;
-$LagOpt = 3600 * 28 unless $LagOpt; # 1 day 3 hours
+$LagOpt = 3600 * 28 unless $LagOpt; # 1 day 4 hours
 
 my $s = NaServer->new( $Hostname, 1, 3 );
 $s->set_transport_type("HTTPS");
@@ -43,10 +54,26 @@ my $snap_iterator = NaElement->new("snapmirror-get-iter");
 my $tag_elem = NaElement->new("tag");
 $snap_iterator->child_add($tag_elem);
 
+my $query_elem;
+my $sminfo_elem;
+if(defined($VolumeName) || defined($VServer)) {
+	$query_elem = NaElement->new("query");
+        $snap_iterator->child_add($query_elem);
+	$sminfo_elem = NaElement->new("snapmirror-info");
+	$query_elem->child_add($sminfo_elem);
+	if(defined($VolumeName)) {
+		$sminfo_elem->child_add_string("destination-volume", $VolumeName);
+	}
+	if(defined($VServer)) {
+		$sminfo_elem->child_add_string("destination-vserver", $VServer);
+	}
+}
+
 my $next = "";
-my $snapmirror_failed;
-my $snapmirror_ok;
+my $snapmirror_failed = 0;
+my $snapmirror_ok = 0;
 my %failed_names;
+my @excluded_volumes;
 
 while(defined($next)){
 	unless($next eq ""){
@@ -78,24 +105,42 @@ while(defined($next)){
 		my $lag = $snap->child_get_string("lag-time");
 		my $dest_vol = $snap->child_get_string("destination-volume");
 		my $current_transfer = $snap->child_get_string("current-transfer-type");
-
+                if ($verbose) {
+                   print "[DEBUG] dest_vol=$dest_vol,\t status=$status,\t healthy=$healthy,\t lag=$lag\n";
+                }
+                if (exists $Excludelist{$dest_vol}) {
+                   push(@excluded_volumes,$dest_vol."\n");
+                   next;
+                }
+                if ($regexp and $excludeliststr) {
+                   if ($dest_vol =~ m/$excludeliststr/) {
+                     push(@excluded_volumes,$dest_vol."\n");
+                     next;
+                   }
+                }
 		if($healthy eq "false"){
-            if(! $current_transfer){
+                   if ($verbose) {
+                      print "[DEBUG] ".Dumper($snap);
+                   }
+                   if(! $current_transfer){
     			$failed_names{$dest_vol} = [ $healthy, $lag ];
     			$snapmirror_failed++;
-    		} elsif ($status eq "transferring"){
+                   } elsif (($status eq "transferring") || ($status eq "finalizing")){
     			$snapmirror_ok++;
-    		}
-        } else {
-            $snapmirror_ok++;
-        }
+    		   }
+                } else {
+                   $snapmirror_ok++;
+                }
 
-        if(defined($lag) && ($lag >= $LagOpt)){
-            unless($failed_names{$dest_vol} || $status eq "transferring"){
-                $failed_names{$dest_vol} = [ $healthy, $lag ];
-                $snapmirror_failed++;
-            }
-        }
+                if(defined($lag) && ($lag >= $LagOpt)){
+                    if ($verbose) {
+                      print "[DEBUG] ".Dumper($snap);
+                    }
+                    unless(($failed_names{$dest_vol}) || ($status eq "transferring") || ($status eq "finalizing")){
+                        $failed_names{$dest_vol} = [ $healthy, $lag ];
+                        $snapmirror_failed++;
+                    }
+                }
 
 	}
 	$next = $snap_output->child_get_string("next-tag");
@@ -104,6 +149,7 @@ while(defined($next)){
 
 if ($snapmirror_failed) {
 	print "CRITICAL: $snapmirror_failed snapmirror(s) failed - $snapmirror_ok snapmirror(s) ok\n";
+	print "Failing snapmirror(s):\n";
 	printf ("%-*s%*s%*s\n", 50, "Name", 10, "Healthy", 10, "Delay");
 	for my $vol ( keys %failed_names ) {
 		my $health_lag = $failed_names{$vol};
@@ -111,9 +157,13 @@ if ($snapmirror_failed) {
 		$health_lag_value[1] = "--- " unless $health_lag_value[1];
 		printf ("%-*s%*s%*s\n", 50, $vol, 10, $health_lag_value[0], 10, $health_lag_value[1] . "s");
 	}
+        print "\nExcluded volume(s):\n";
+        print "@excluded_volumes\n";
 	exit 2;
 } else {
 	print "OK: $snapmirror_ok snapmirror(s) ok\n";
+        print "\nExcluded volume(s):\n";
+        print "@excluded_volumes\n";
 	exit 0;
 }
 
@@ -123,13 +173,14 @@ __END__
 
 =head1 NAME
 
-check_cdot_snapmirror - Checks SnapMirror Healthnes
+check_cdot_snapmirror - Checks SnapMirror Healthness
 
 =head1 SYNOPSIS
 
-check_cdot_snapmirror.pl --hostname HOSTNAME --username USERNAME \
-           --password PASSWORD --warning PERCENT_WARNING \
-           --critical PERCENT_CRITICAL
+check_cdot_snapmirror.pl --hostname HOSTNAME --username USERNAME
+           --password PASSWORD [--lag DELAY-SECONDS]
+           [--volume VOLUME-NAME] [--vserver VSERVER-NAME] 
+           [--exclude VOLUME-NAME] [--regexp] [--verbose]
 
 =head1 DESCRIPTION
 
@@ -155,6 +206,26 @@ The Login Password of the NetApp to monitor
 
 Snapmirror delay in Seconds. Default 28h
 
+=item --volume VOLUME-NAME
+
+Name of the destination volume to be checked. If not specified, check all volumes.
+
+=item --vserver VSERVER-NAME
+
+Name of the destination vserver to be checked. If not specificed, search only the base server.
+
+=item --exclude
+
+Optional: The name of a volume that has to be excluded from the checks (multiple exclude item for multiple volumes)
+
+=item --regexp
+
+Optional: Enable regexp matching for the exclusion list
+
+=item -v | --verbose
+
+Enable verbose mode
+
 =item -help
 
 =item -?
