@@ -1,5 +1,6 @@
 #!/usr/bin/perl
 
+# nagios: -epn
 # --
 # check_cdot_sparedisk - Check NetApp System Spare Disks
 # Copyright (C) 2013 noris network AG, http://www.noris.net/
@@ -12,7 +13,7 @@
 use strict;
 use warnings;
 
-use lib "/usr/lib/netapp-manageability-sdk-5.1/lib/perl/NetApp";
+use lib "/usr/lib/netapp-manageability-sdk/lib/perl/NetApp";
 use NaServer;
 use NaElement;
 use Getopt::Long;
